@@ -4,11 +4,12 @@ import typing
 from datetime import date
 from pathlib import Path
 
+import boto3
 from google.cloud import storage
 from google.oauth2 import service_account
 
 from postgres_backup.schemas import CloudProviders, CloudStorageType
-from postgres_backup.upload import GCStorage
+from postgres_backup.upload import AWSStorage, GCStorage
 from postgres_backup.utils import logger, settings
 
 try:
@@ -46,7 +47,8 @@ class Backup:
         self,
         local_file_path: typing.Optional[str] = './',
         out_file_name: typing.Union[str, Path] = 'backup',
-        out_file_extension: typing.Union[str, Path] = '.gz'
+        out_file_extension: typing.Union[str, Path] = '.gz',
+        table_names: typing.Optional[typing.List[str]] = [],
     ) -> str:
 
         username, password, host, port, db_name = self.get_db_params()
@@ -76,6 +78,7 @@ class Backup:
                 username,
                 db_name,
                 '-E UTF-8',
+                ' '.join(f'-t {table_name}' for table_name in table_names),
                 _out=f)
 
         logger.info('Finished creation of backup')
@@ -95,9 +98,15 @@ class Backup:
             typing.Dict[str, str]
         ] = settings.GOOGLE_CLOUD_CERTIFICATION,
         create_bucket: typing.Optional[bool] = False,
-        storage_class=CloudStorageType.NEARLINE.value
+        storage_class=CloudStorageType.NEARLINE.value,
+        # For uploading to AWS
+        aws_server_public_key: typing.Optional[str] = settings.AWS_SERVER_PUBLIC_KEY,
+        aws_server_private_key: typing.Optional[str] = settings.AWS_SERVER_PRIVATE_KEY,
+        region_name: typing.Optional[str] = settings.REGION_NAME
     ):
 
+        file_name = self.file_name if self.file_name else file_name
+
         if provider == 'google_cloud_storage':
             credentials = service_account.Credentials.from_service_account_info(
                 google_cloud_certification
@@ -109,8 +118,6 @@ class Backup:
             )
             gcs_storage = GCStorage(client=client, bucket_name=bucket_name)
 
-            file_name = self.file_name if self.file_name else file_name
-
             gcs_storage.upload_file(
                 file_name=file_name,
                 local_file_path=self.local_file_path,
@@ -120,6 +127,32 @@ class Backup:
                 storage_class=storage_class
             )
 
+        elif provider == 'amazon_web_services':
+            # Create a Boto3 Session
+            session = boto3.Session(
+                aws_server_public_key=aws_server_public_key,
+                aws_server_private_key=aws_server_private_key,
+                region_name=region_name
+            )
+
+            # Select the resource for which we want to work
+            s3_resource = session.resource('s3')
+
+            aws_storage = AWSStorage(
+                s3_resource,
+                bucket_name,
+                region_name
+            )
+
+            aws_storage.upload_file(
+                file_name=file_name,
+                local_file_path=self.local_file_path,
+                remote_file_path=remote_file_path,
+                clean=clean,
+                create_bucket=create_bucket,
+                storage_class=storage_class
+            )
+
 
 if __name__ == '__main__':
     backup = Backup()
